(ns wanijo-pipeline.core
  (:require
   [wanijo-pipeline.pipeline :as pipeline]
   [wanijo-pipeline.ui-selection :as ui-selection]
   [org.httpkit.server :as http-kit]
   [lambdacd.runners :as runners]
   [lambdacd.core :as lambdacd]
   [clojure.tools.logging :as log]
   [wanijo-pipeline.formulare-pipeline :as fp])
  (:import (java.nio.file.attribute FileAttribute)
           (java.nio.file Files LinkOption))
  (:gen-class))

(defn- home-dir [pipeline-name]
 (str (System/getProperty "user.home") "/wanijo-pipeline/" pipeline-name))

(defn wanijo-pipeline []
  (lambdacd/assemble-pipeline pipeline/pipeline-def
                              {:home-dir (home-dir "wanijo")
                               :name "wanijo pipeline"}))

(defn formulare-pipeline []
  (lambdacd/assemble-pipeline fp/pipeline-def
                              {:home-dir (create-temp-dir "formulare")
                               :name "formulare pipeline"}))

(defn -main [& args]
  (let [wanijo-pipeline (wanijo-pipeline)
        formulare-pipeline (formulare-pipeline)
        app (ui-selection/ui-routes wanijo-pipeline
                                    formulare-pipeline)]
    ;; this starts the pipeline and runs one build after the other.
    ;; there are other runners and you can define your own as well.
    (runners/start-one-run-after-another wanijo-pipeline)
    (runners/start-one-run-after-another formulare-pipeline)
    ;; start the webserver to serve the UI
    (http-kit/run-server app {:port 30500})))
